==> lra-client-5.11.0.Final-sources.jar: io/narayana/lra/client/ParentLRAJoinException.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2017, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package io.narayana.lra.client;


import javax.ws.rs.core.Response;

public class ParentLRAJoinException extends Exception {

    private static final long serialVersionUID = -5216874174212926195L;
    private final Response reason;

    public ParentLRAJoinException(String lraId, String message, Response reason) {
        super(String.format("%s, lra id: %s", message, lraId));

        this.reason = reason;
    }

    public Response getReason() {
        return reason;
    }
}

==> lra-client-5.12.5.Final-sources.jar: io/narayana/lra/client/ParentLRAJoinException.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2017, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package io.narayana.lra.client;


import jakarta.ws.rs.core.Response;

public class ParentLRAJoinException extends Exception {

    private static final long serialVersionUID = -5216874174212926195L;
    private final Response reason;

    public ParentLRAJoinException(String lraId, String message, Response reason) {
        super(String.format("%s, lra id: %s", message, lraId));

        this.reason = reason;
    }

    public Response getReason() {
        return reason;
    }
}
